==> gnomeicu-0.65.tar.gz: gnomeicu-0.65/src/loadpixmap.c <==
#include "gnomeicu.h"
#include "pixmaps.h"
#include "loadpixmap.h"

#include "xpms/gnomeicu-blank.xpm"
#include "xpms/gnomeicu-message.xpm"
#include "xpms/gnomeicu-url.xpm"
#include "xpms/gnomeicu-auth.xpm"
#include "xpms/gnomeicu-away.xpm"
#include "xpms/gnomeicu-na.xpm"
#include "xpms/gnomeicu-occ.xpm"
#include "xpms/gnomeicu-dnd.xpm"
#include "xpms/gnomeicu-ffc.xpm"
#include "xpms/gnomeicu-inv.xpm"
#include "xpms/gnomeicu-online.xpm"
#include "xpms/gnomeicu-offline.xpm"
#include "xpms/gnomeicu-chat.xpm"
#include "xpms/gnomeicu-chat2.xpm"
#include "xpms/gnomeicu-file.xpm"
#include "xpms/gnomeicu-info.xpm"
#include "xpms/gnomeicu-nomess.xpm"

void init_pixmaps( GtkStyle *style, GtkWidget *main_window )
{
	GdkImlibImage *im;

#ifdef TRACE_FUNCTION
	g_print( "init_pixmaps\n" );
#endif

	im = gdk_imlib_create_image_from_xpm_data( icon_blank_xpm );
	gdk_imlib_render( im, im->rgb_width, im->rgb_height );
	icon_blank_pixmap = gdk_imlib_copy_image( im );
	icon_blank_bitmap = gdk_imlib_copy_mask( im );
	gdk_imlib_destroy_image( im );


	im = gdk_imlib_create_image_from_xpm_data( icon_message_xpm );
	gdk_imlib_render( im, im->rgb_width, im->rgb_height );
	icon_message_pixmap = gdk_imlib_copy_image( im );
	icon_message_bitmap = gdk_imlib_copy_mask( im );
	gdk_imlib_destroy_image( im );

	im = gdk_imlib_create_image_from_xpm_data( icon_url_xpm );
	gdk_imlib_render( im, im->rgb_width, im->rgb_height );
	icon_url_pixmap = gdk_imlib_copy_image( im );
	icon_url_bitmap = gdk_imlib_copy_mask( im );
	gdk_imlib_destroy_image( im );

	im = gdk_imlib_create_image_from_xpm_data( icon_auth_xpm );
	gdk_imlib_render( im, im->rgb_width, im->rgb_height );
	icon_auth_pixmap = gdk_imlib_copy_image( im );
	icon_auth_bitmap = gdk_imlib_copy_mask( im );
	gdk_imlib_destroy_image( im );

	im = gdk_imlib_create_image_from_xpm_data( icon_away_xpm );
	gdk_imlib_render( im, im->rgb_width, im->rgb_height );
	icon_away_pixmap = gdk_imlib_copy_image( im );
	icon_away_bitmap = gdk_imlib_copy_mask( im );
	gdk_imlib_destroy_image( im );

	im = gdk_imlib_create_image_from_xpm_data( icon_na_xpm );
	gdk_imlib_render( im, im->rgb_width, im->rgb_height );
	icon_na_pixmap = gdk_imlib_copy_image( im );
	icon_na_bitmap = gdk_imlib_copy_mask( im );
	gdk_imlib_destroy_image( im );

	im = gdk_imlib_create_image_from_xpm_data( icon_occ_xpm );
	gdk_imlib_render( im, im->rgb_width, im->rgb_height );
	icon_occ_pixmap = gdk_imlib_copy_image( im );
	icon_occ_bitmap = gdk_imlib_copy_mask( im );
	gdk_imlib_destroy_image( im );

	im = gdk_imlib_create_image_from_xpm_data( icon_dnd_xpm );
	gdk_imlib_render( im, im->rgb_width, im->rgb_height );
	icon_dnd_pixmap = gdk_imlib_copy_image( im );
	icon_dnd_bitmap = gdk_imlib_copy_mask( im );
	gdk_imlib_destroy_image( im );

	im = gdk_imlib_create_image_from_xpm_data( icon_ffc_xpm );
	gdk_imlib_render( im, im->rgb_width, im->rgb_height );
	icon_ffc_pixmap = gdk_imlib_copy_image( im );
	icon_ffc_bitmap = gdk_imlib_copy_mask( im );
	gdk_imlib_destroy_image( im );

	im = gdk_imlib_create_image_from_xpm_data( icon_inv_xpm );
	gdk_imlib_render( im, im->rgb_width, im->rgb_height );
	icon_inv_pixmap = gdk_imlib_copy_image( im );
	icon_inv_bitmap = gdk_imlib_copy_mask( im );
	gdk_imlib_destroy_image( im );

	im = gdk_imlib_create_image_from_xpm_data( icon_online_xpm );
	gdk_imlib_render( im, im->rgb_width, im->rgb_height );
	icon_online_pixmap = gdk_imlib_copy_image( im );
	icon_online_bitmap = gdk_imlib_copy_mask( im );
	gdk_imlib_destroy_image( im );

	im = gdk_imlib_create_image_from_xpm_data( icon_offline_xpm );
	gdk_imlib_render( im, im->rgb_width, im->rgb_height );
	icon_offline_pixmap = gdk_imlib_copy_image( im );
	icon_offline_bitmap = gdk_imlib_copy_mask( im );
	gdk_imlib_destroy_image( im );

	im = gdk_imlib_create_image_from_xpm_data( icon_chat_xpm );
	gdk_imlib_render( im, im->rgb_width, im->rgb_height );
	icon_chat_pixmap = gdk_imlib_copy_image( im );
	icon_chat_bitmap = gdk_imlib_copy_mask( im );
	gdk_imlib_destroy_image( im );

	im = gdk_imlib_create_image_from_xpm_data( icon_chat2_xpm );
	gdk_imlib_render( im, im->rgb_width, im->rgb_height );
	icon_chat2_pixmap = gdk_imlib_copy_image( im );
	icon_chat2_bitmap = gdk_imlib_copy_mask( im );
	gdk_imlib_destroy_image( im );

	im = gdk_imlib_create_image_from_xpm_data( icon_file_xpm );
	gdk_imlib_render( im, im->rgb_width, im->rgb_height );
	icon_file_pixmap = gdk_imlib_copy_image( im );
	icon_file_bitmap = gdk_imlib_copy_mask( im );
	gdk_imlib_destroy_image( im );

	im = gdk_imlib_create_image_from_xpm_data( icon_info_xpm );
	gdk_imlib_render( im, im->rgb_width, im->rgb_height );
	icon_info_pixmap = gdk_imlib_copy_image( im );
	icon_info_bitmap = gdk_imlib_copy_mask( im );
	gdk_imlib_destroy_image( im );

	im = gdk_imlib_create_image_from_xpm_data( nomess_xpm );
	gdk_imlib_render( im, im->rgb_width, im->rgb_height );
	nomess_pixmap = gdk_imlib_copy_image( im );
	nomess_bitmap = gdk_imlib_copy_mask( im );
	gdk_imlib_destroy_image( im );
}

==> gnomeicu_0.90b.orig.tar.gz: gnomeicu-0.90b.orig/src/loadpixmap.c <==
/*****************************
 Load XPMs into memory
 (c) 1999 Jeremy Wise
 GnomeICU
******************************/

/*** GnomeICU headers ***/
#include "common.h"

/*** XPMs ***/
#include "xpms/gnomeicu-blank.xpm"
#include "xpms/gnomeicu-message.xpm"
#include "xpms/gnomeicu-url.xpm"
#include "xpms/gnomeicu-auth.xpm"
#include "xpms/gnomeicu-away.xpm"
#include "xpms/gnomeicu-na.xpm"
#include "xpms/gnomeicu-occ.xpm"
#include "xpms/gnomeicu-dnd.xpm"
#include "xpms/gnomeicu-ffc.xpm"
#include "xpms/gnomeicu-inv.xpm"
#include "xpms/gnomeicu-online.xpm"
#include "xpms/gnomeicu-offline.xpm"
#include "xpms/gnomeicu-chat.xpm"
#include "xpms/gnomeicu-file.xpm"
#include "xpms/gnomeicu-info.xpm"
#include "xpms/gnomeicu-contact.xpm"
#include "xpms/gnomeicu-hist.xpm"
#include "xpms/eye_na.xpm"
#include "xpms/ok.xpm"
#include "xpms/cancel.xpm"
#include "xpms/rename.xpm"

/*** Global functions ***/
void init_pixmaps( GtkStyle *style, GtkWidget *main_window )
{
	GdkImlibImage *im;

#ifdef TRACE_FUNCTION
	g_print( "init_pixmaps\n" );
#endif

	im = gdk_imlib_create_image_from_xpm_data( icon_blank_xpm );
	gdk_imlib_render( im, im->rgb_width, im->rgb_height );
	icon_blank_pixmap = gdk_imlib_copy_image( im );
	icon_blank_bitmap = gdk_imlib_copy_mask( im );
	gdk_imlib_destroy_image( im );

	im = gdk_imlib_create_image_from_xpm_data( noaction_xpm );
	gdk_imlib_render( im, im->rgb_width, im->rgb_height );
	still_eyes_pixmap = gdk_imlib_copy_image( im );
	still_eyes_bitmap = gdk_imlib_copy_mask( im );
	gdk_imlib_destroy_image( im );

	im = gdk_imlib_create_image_from_xpm_data( icon_message_xpm );
	gdk_imlib_render( im, im->rgb_width, im->rgb_height );
	icon_message_pixmap = gdk_imlib_copy_image( im );
	icon_message_bitmap = gdk_imlib_copy_mask( im );
	gdk_imlib_destroy_image( im );

	im = gdk_imlib_create_image_from_xpm_data( icon_url_xpm );
	gdk_imlib_render( im, im->rgb_width, im->rgb_height );
	icon_url_pixmap = gdk_imlib_copy_image( im );
	icon_url_bitmap = gdk_imlib_copy_mask( im );
	gdk_imlib_destroy_image( im );

	im = gdk_imlib_create_image_from_xpm_data( icon_auth_xpm );
	gdk_imlib_render( im, im->rgb_width, im->rgb_height );
	icon_auth_pixmap = gdk_imlib_copy_image( im );
	icon_auth_bitmap = gdk_imlib_copy_mask( im );
	gdk_imlib_destroy_image( im );

	im = gdk_imlib_create_image_from_xpm_data( icon_away_xpm );
	gdk_imlib_render( im, im->rgb_width, im->rgb_height );
	icon_away_pixmap = gdk_imlib_copy_image( im );
	icon_away_bitmap = gdk_imlib_copy_mask( im );
	gdk_imlib_destroy_image( im );

	im = gdk_imlib_create_image_from_xpm_data( icon_na_xpm );
	gdk_imlib_render( im, im->rgb_width, im->rgb_height );
	icon_na_pixmap = gdk_imlib_copy_image( im );
	icon_na_bitmap = gdk_imlib_copy_mask( im );
	gdk_imlib_destroy_image( im );

	im = gdk_imlib_create_image_from_xpm_data( icon_occ_xpm );
	gdk_imlib_render( im, im->rgb_width, im->rgb_height );
	icon_occ_pixmap = gdk_imlib_copy_image( im );
	icon_occ_bitmap = gdk_imlib_copy_mask( im );
	gdk_imlib_destroy_image( im );

	im = gdk_imlib_create_image_from_xpm_data( icon_dnd_xpm );
	gdk_imlib_render( im, im->rgb_width, im->rgb_height );
	icon_dnd_pixmap = gdk_imlib_copy_image( im );
	icon_dnd_bitmap = gdk_imlib_copy_mask( im );
	gdk_imlib_destroy_image( im );

	im = gdk_imlib_create_image_from_xpm_data( icon_ffc_xpm );
	gdk_imlib_render( im, im->rgb_width, im->rgb_height );
	icon_ffc_pixmap = gdk_imlib_copy_image( im );
	icon_ffc_bitmap = gdk_imlib_copy_mask( im );
	gdk_imlib_destroy_image( im );

	im = gdk_imlib_create_image_from_xpm_data( icon_inv_xpm );
	gdk_imlib_render( im, im->rgb_width, im->rgb_height );
	icon_inv_pixmap = gdk_imlib_copy_image( im );
	icon_inv_bitmap = gdk_imlib_copy_mask( im );
	gdk_imlib_destroy_image( im );

	im = gdk_imlib_create_image_from_xpm_data( icon_online_xpm );
	gdk_imlib_render( im, im->rgb_width, im->rgb_height );
	icon_online_pixmap = gdk_imlib_copy_image( im );
	icon_online_bitmap = gdk_imlib_copy_mask( im );
	gdk_imlib_destroy_image( im );

	im = gdk_imlib_create_image_from_xpm_data( icon_offline_xpm );
	gdk_imlib_render( im, im->rgb_width, im->rgb_height );
	icon_offline_pixmap = gdk_imlib_copy_image( im );
	icon_offline_bitmap = gdk_imlib_copy_mask( im );
	gdk_imlib_destroy_image( im );

	im = gdk_imlib_create_image_from_xpm_data( icon_chat_xpm );
	gdk_imlib_render( im, im->rgb_width, im->rgb_height );
	icon_chat_pixmap = gdk_imlib_copy_image( im );
	icon_chat_bitmap = gdk_imlib_copy_mask( im );
	gdk_imlib_destroy_image( im );

	im = gdk_imlib_create_image_from_xpm_data( icon_file_xpm );
	gdk_imlib_render( im, im->rgb_width, im->rgb_height );
	icon_file_pixmap = gdk_imlib_copy_image( im );
	icon_file_bitmap = gdk_imlib_copy_mask( im );
	gdk_imlib_destroy_image( im );

	im = gdk_imlib_create_image_from_xpm_data( icon_info_xpm );
	gdk_imlib_render( im, im->rgb_width, im->rgb_height );
	icon_info_pixmap = gdk_imlib_copy_image( im );
	icon_info_bitmap = gdk_imlib_copy_mask( im );
	gdk_imlib_destroy_image( im );

	im = gdk_imlib_create_image_from_xpm_data( icon_contact_xpm );
	gdk_imlib_render( im, im->rgb_width, im->rgb_height );
	icon_contact_pixmap = gdk_imlib_copy_image( im );
	icon_contact_bitmap = gdk_imlib_copy_mask( im );
	gdk_imlib_destroy_image( im );

	im = gdk_imlib_create_image_from_xpm_data( icon_hist_xpm );
	gdk_imlib_render( im, im->rgb_width, im->rgb_height );
	icon_hist_pixmap = gdk_imlib_copy_image( im );
	icon_hist_bitmap = gdk_imlib_copy_mask( im );
	gdk_imlib_destroy_image( im );

	im = gdk_imlib_create_image_from_xpm_data( icon_ok_xpm );
	gdk_imlib_render( im, im->rgb_width, im->rgb_height );
	icon_ok_pixmap = gdk_imlib_copy_image( im );
	icon_ok_bitmap = gdk_imlib_copy_mask( im );
	gdk_imlib_destroy_image( im );

	im = gdk_imlib_create_image_from_xpm_data( icon_cancel_xpm );
	gdk_imlib_render( im, im->rgb_width, im->rgb_height );
	icon_cancel_pixmap = gdk_imlib_copy_image( im );
	icon_cancel_bitmap = gdk_imlib_copy_mask( im );
	gdk_imlib_destroy_image( im );

	im = gdk_imlib_create_image_from_xpm_data( icon_rename_xpm );
	gdk_imlib_render( im, im->rgb_width, im->rgb_height );
	icon_rename_pixmap = gdk_imlib_copy_image( im );
	icon_rename_bitmap = gdk_imlib_copy_mask( im );
	gdk_imlib_destroy_image( im );
}
